@@ -42,6 +42,8 @@
 #include <QDebug>
 
 #include "kacceleratormanager_p.h"
+#include "loggingcategory.h"
+#include "common_helpers_p.h"
 
 /*********************************************************************
 
@@ -91,7 +93,7 @@ void KAcceleratorManagerPrivate::Item::addChild(Item *item)
 void KAcceleratorManagerPrivate::manage(QWidget *widget)
 {
     if (!widget) {
-        qDebug() << "null pointer given to manage";
+        qCDebug(KWidgetsAddonsLog) << "null pointer given to manage";
         return;
     }
 
@@ -196,7 +198,7 @@ void KAcceleratorManagerPrivate::traverseChildren(QWidget *widget, Item *item)
             continue;
         }
 
-        if (!w->isVisibleTo(widget) || (w->isTopLevel() && qobject_cast<QMenu *>(w) == NULL)) {
+        if (!w->isVisibleTo(widget) || (w->isTopLevel() && qobject_cast<QMenu *>(w) == nullptr)) {
             continue;
         }
 
@@ -550,7 +552,7 @@ void KAccelString::calculateWeights(int initialWeight)
         // try to preserve the wanted accelarators
         if ((int)pos == accel()) {
             weight += KAccelManagerAlgorithm::WANTED_ACCEL_EXTRA_WEIGHT;
-            // qDebug() << "wanted " << m_pureText << " " << KAcceleratorManagerPrivate::standardName(m_origText);
+            // qCDebug(KWidgetsAddonsLog) << "wanted " << m_pureText << " " << KAcceleratorManagerPrivate::standardName(m_origText);
             if (KAcceleratorManagerPrivate::standardName(m_origText))  {
                 weight += KAccelManagerAlgorithm::STANDARD_ACCEL;
             }
@@ -615,7 +617,7 @@ void KAccelString::dump()
     for (int i = 0; i < m_weight.count(); ++i) {
         s += QStringLiteral("%1(%2) ").arg(pure()[i]).arg(m_weight[i]);
     }
-    qDebug() << "s " << s;
+    qCDebug(KWidgetsAddonsLog) << "s " << s;
 }
 
 /*********************************************************************
@@ -693,7 +695,7 @@ void KAccelManagerAlgorithm::findAccelerators(KAccelStringList &result, QString
 
 /*********************************************************************
 
- class KPopupAccelManager - managing QPopupMenu widgets dynamically
+ class KPopupAccelManager - managing QMenu widgets dynamically
 
  *********************************************************************/
 
@@ -701,7 +703,7 @@ KPopupAccelManager::KPopupAccelManager(QMenu *popup)
     : QObject(popup), m_popup(popup), m_count(-1)
 {
     aboutToShow(); // do one check and then connect to show
-    connect(popup, SIGNAL(aboutToShow()), SLOT(aboutToShow()));
+    connect(popup, &QMenu::aboutToShow, this, &KPopupAccelManager::aboutToShow);
 }
 
 void KPopupAccelManager::aboutToShow()
@@ -764,6 +766,18 @@ void KPopupAccelManager::findMenuEntries(KAccelStringList &list)
     }
 }
 
+// Duplicated from qaction.cpp
+static QString copy_of_qt_strippedText(QString s)
+{
+    s.remove(QStringLiteral("..."));
+    for (int i = 0; i < s.size(); ++i) {
+        if (s.at(i) == QLatin1Char('&')) {
+            s.remove(i, 1);
+        }
+    }
+    return s.trimmed();
+}
+
 void KPopupAccelManager::setMenuEntries(const KAccelStringList &list)
 {
     uint cnt = 0;
@@ -772,6 +786,14 @@ void KPopupAccelManager::setMenuEntries(const KAccelStringList &list)
             continue;
         }
 
+        QString iconText = maction->iconText();
+        const QString oldText = maction->text();
+        // Check if iconText was generated by Qt. In that case ignore it (no support for CJK accelerators) and set it from the text.
+        if (iconText == copy_of_qt_strippedText(oldText)) {
+            iconText = removeAcceleratorMarker(oldText);
+        }
+        maction->setIconText(iconText);
+
         if (KAcceleratorManagerPrivate::checkChange(list[cnt])) {
             maction->setText(list[cnt].accelerated());
         }
@@ -782,14 +804,14 @@ void KPopupAccelManager::setMenuEntries(const KAccelStringList &list)
 void KPopupAccelManager::manage(QMenu *popup)
 {
     // don't add more than one manager to a popup
-    if (popup->findChild<KPopupAccelManager *>(QString()) == 0) {
+    if (popup->findChild<KPopupAccelManager *>(QString()) == nullptr) {
         new KPopupAccelManager(popup);
     }
 }
 
 void QWidgetStackAccelManager::manage(QStackedWidget *stack)
 {
-    if (stack->findChild<QWidgetStackAccelManager *>(QString()) == 0) {
+    if (stack->findChild<QWidgetStackAccelManager *>(QString()) == nullptr) {
         new QWidgetStackAccelManager(stack);
     }
 }
@@ -798,7 +820,7 @@ QWidgetStackAccelManager::QWidgetStackAccelManager(QStackedWidget *stack)
     : QObject(stack), m_stack(stack)
 {
     currentChanged(stack->currentIndex()); // do one check and then connect to show
-    connect(stack, SIGNAL(currentChanged(int)), SLOT(currentChanged(int)));
+    connect(stack, &QStackedWidget::currentChanged, this, &QWidgetStackAccelManager::currentChanged);
 }
 
 bool QWidgetStackAccelManager::eventFilter(QObject *watched, QEvent *e)
