@@ -82,7 +82,20 @@ QSize KSqueezedTextLabel::sizeHint() const
     if (textWidth > maxWidth) {
         textWidth = maxWidth;
     }
-    return QSize(textWidth, QLabel::sizeHint().height());
+    const int chromeWidth = width() - contentsRect().width();
+    return QSize(textWidth + chromeWidth, QLabel::sizeHint().height());
+}
+
+void KSqueezedTextLabel::setIndent(int indent)
+{
+    QLabel::setIndent(indent);
+    squeezeTextToLabel();
+}
+
+void KSqueezedTextLabel::setMargin(int margin)
+{
+    QLabel::setMargin(margin);
+    squeezeTextToLabel();
 }
 
 void KSqueezedTextLabel::setText(const QString &text)
@@ -100,7 +113,7 @@ void KSqueezedTextLabel::clear()
 void KSqueezedTextLabel::squeezeTextToLabel()
 {
     QFontMetrics fm(fontMetrics());
-    int labelWidth = size().width();
+    const int labelWidth = contentsRect().width();
     QStringList squeezedLines;
     bool squeezed = false;
     Q_FOREACH (const QString &line, d->fullText.split(QLatin1Char('\n'))) {
@@ -122,6 +135,40 @@ void KSqueezedTextLabel::squeezeTextToLabel()
     }
 }
 
+QRect KSqueezedTextLabel::contentsRect() const
+{
+    // calculation according to API docs for QLabel::indent
+    const int margin = this->margin();
+    int indent = this->indent();
+    if (indent < 0) {
+        if (frameWidth() == 0) {
+            indent = 0;
+        } else {
+            indent = fontMetrics().width(QLatin1Char('x')) / 2 - margin;
+        }
+    }
+
+    QRect result = QLabel::contentsRect();
+    if (indent > 0) {
+        const int alignment = this->alignment();
+        if (alignment & Qt::AlignLeft) {
+            result.setLeft(result.left() + indent);
+        }
+        if (alignment & Qt::AlignTop) {
+            result.setTop(result.top() + indent);
+        }
+        if (alignment & Qt::AlignRight) {
+            result.setRight(result.right() - indent);
+        }
+        if (alignment & Qt::AlignBottom) {
+            result.setBottom(result.bottom() - indent);
+        }
+    }
+
+    result.adjust(margin, margin, -margin, -margin);
+    return result;
+}
+
 void KSqueezedTextLabel::setAlignment(Qt::Alignment alignment)
 {
     // save fullText and restore it
